@@ -3,7 +3,7 @@ package App::CekBpom;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-09'; # DATE
 our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -82,6 +82,21 @@ _
             slurpy => 1,
         },
     },
+    examples => [
+        {
+            summary => 'By default search against name (nama_produk) and brand (merk)',
+            argv => ["hichew", "hi-chew", "hi chew"],
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Adding --trace will show query details, --format html+datatables is convenient to see/search/sort results in browser',
+            src => "[[prog]] hichew hi-chew 'hi chew' --trace --format html+datatables",
+            src_plang => "bash",
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub cek_bpom {
     require HTTP::CookieJar::LWP;
@@ -199,7 +214,7 @@ App::CekBpom - Check BPOM products via the command-line (CLI interface for cekbp
 
 =head1 VERSION
 
-This document describes version 0.006 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-09.
+This document describes version 0.007 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-09.
 
 =head1 DESCRIPTION
 
@@ -216,6 +231,16 @@ Usage:
 
 Search BPOM products via https:E<sol>E<sol>cekbpom.pom.go.idE<sol>.
 
+Examples:
+
+=over
+
+=item * By default search against name (nama_produk) and brand (merk):
+
+ cek_bpom( queries => ["hichew", "hi-chew", "hi chew"]);
+
+=back
+
 Uses L<LWP::UserAgent::Plugin> so you can add retry, caching, or additional
 HTTP client behavior by setting C<LWP_USERAGENT_PLUGINS> environment variable.
 
